/*BEGIN CMVC */
//*************************************************************************
//
//  Workfile: %W%
//  Last update: %E% %U%
//  SCCS path, id: %F% %I%
//
//************************************************************************/
/*END CMVC */
/*BEGIN COPYRIGHT */
//*************************************************************************
//
//  Licensed Materials - Property of IBM
//  WA82 SupportPac
//  (c) Copyright IBM Corp. 2000, 2001, 2002, 2003
//  US Government Users Restricted Rights - Use, duplication or
//  disclosure restricted by GSA ADP Schedule Contract
//  with IBM Corp.
//
//************************************************************************/
/*END COPYRIGHT */
/*BEGIN DISCLAIMER */
//*************************************************************************
//  DISCLAIMER
//  ----------
//  This material contains programming source code for your consideration.
//  These examples have not been thoroughly tested under all conditions.
//  IBM, therefore, cannot guarantee or imply reliability, serviceability,
//  or function of these programs.
//  ALL PROGRAMS CONTAINED HEREIN ARE PROVIDED TO YOU "AS IS", WITHOUT ANY
//  WARRANTIES (EXPRESS OR IMPLIED) OR SUPPORT WHATSOEVER, INCLUDING BUT
//  NOT LIMITED TO ANY IMPLIED WARRANTIES OF MERCHANTABILITY OR FITNESS
//  FOR A PARTICULAR PURPOSE.
//************************************************************************/
/*END DISCLAIMER */

package com.ibm.workflow.sample.upes;

import java.io.*;
import java.util.*;
import com.ibm.mq.*;

public class ShutdownUPES
{
  private String         fileName;

  public static void main( String[] args )
  {
    if ( args.length != 1 ) {
      System.out.println( "Usage: java ShutdownUPES PropertiesFile" );
      System.exit( 1 );
    }
    ShutdownUPES shutdownUPES = new ShutdownUPES( args[ 0 ] );
    shutdownUPES.run( );
  }

  public ShutdownUPES( String fileName )
  {
    this.fileName = fileName;
  }

  public void run( )
  {
    System.out.println( "MQSeries Workflow WebCredit Example (SupportPac WA82) - UPES Shutdown" );
    System.out.println( "---------------------------------------------------------------------" );
    System.out.println( "Initializing UPES Shutdown" );
    Properties p = new Properties( );
    try {
      p.load( new FileInputStream( fileName ) );

      String queueManagerName = p.getProperty( "MQ.QueueManagerName" );
      String queueName        = p.getProperty( "MQ.QueueName"        );

      System.out.println( "  Connecting to MQSeries Queue Manager '" + queueManagerName +"'" );
      MQQueueManager queueManager = new MQQueueManager( queueManagerName );

      System.out.println( "  Accessing Queue '" + queueName +"'" );
      int openOptions = MQC.MQOO_INPUT_AS_Q_DEF | MQC.MQOO_OUTPUT;
      MQQueue queue = queueManager.accessQueue( queueName,
                                                openOptions,
                                                null, null, null );

      MQMessage message = new MQMessage( );
      message.writeString( "QUIT" );

      System.out.println( "  Writing Message onto Queue" );
      queue.put( message );

      System.out.println( "  Closing Queue" );
      queue.close( );
      System.out.println( "  Disconnecting from Queue Manager" );
      queueManager.disconnect( );
      System.out.println( "UPES Shutdown finished" );
    }
    catch( Exception xcpt ) {
      xcpt.printStackTrace( );
      System.exit( 1 );
    }
  }
}
